@@ -11,16 +11,15 @@
 
 const int Energizer::POINTS = 50;
 
-Energizer::Energizer(qreal p_x, qreal p_y, Maze *p_maze, const QString &p_imageId) :  Element(p_x, p_y, p_maze)
+Energizer::Energizer(qreal p_x, qreal p_y, Maze *p_maze, const QString &p_imageId)
+    : Element(p_x, p_y, p_maze)
 {
     Element::setImageId(p_imageId);
     m_points = Energizer::POINTS;
     m_type = Element::ENERGYZER;
 }
 
-Energizer::~Energizer()
-{
-}
+Energizer::~Energizer() = default;
 
 void Energizer::doActionOnCollision(Kapman *p_kapman)
 {
@@ -29,3 +28,4 @@ void Energizer::doActionOnCollision(Kapman *p_kapman)
     m_maze->decrementNbElem();
 }
 
+#include "moc_energizer.cpp"
